import { Drawer, Flex, Toast, Icon, ActivityIndicator } from 'antd-mobile'
import React, { useEffect, useState } from 'react'
import styles from './AreaSelect.less'
import { getCountryPhoneCode } from '@/services/api'

interface IDetail {
  country: string
}

export default (props: any) => {
  const [loading, setLoading] = useState(true)
  const [list, setList] = useState([])
  const [allList, setAllList] = useState([])
  const [country, setCountry] = useState('')


  useEffect(() => {
    fetchCountryPhoneCode()   //获取区号
  }, [])

  //获取区号
  const fetchCountryPhoneCode = async () => {
    const res: any = await getCountryPhoneCode()
    if (res.success) {
      setLoading(false)
      const list = res.data.list || []
      setList(list)
      setAllList(list)
    } else {
      setLoading(false)
      Toast.fail('获取国家区号失败', 1.5)
    }
  }

  //搜索
  const searchCountry = () => {
    const newList: any = []
    for (let detail of list) {
      const item = detail
      if (item['country']) {
        const countryStr = item['country'] || ''
        if (countryStr.indexOf(country) !== -1) {
          newList.push(item)
        }
      }
    }
    setList(newList)
  }

  const handleInput = (e: any) => {
    setCountry(e.target.value)
    if (!e.target.value) {
      setList(allList)
    }
  }

  //选择
  const pickItem = (item: any) => {
    if (props.pickItem) {
      props.pickItem(item)
    }
  }

  return (
    <div className={styles.area}>
      <Flex className={styles.search} align="center">
        <div className={styles['view-input']}>
          <input placeholder="输入地区名称" value={country} onChange={handleInput} />
          <img className={styles['icon-earch']} src={require('@/assets/icon_search.png')} />
        </div>
        <div className={styles['search-text']} onClick={searchCountry}>搜索</div>
      </Flex>
      {loading ? <ActivityIndicator toast text="加载中" /> : (
        <div className={styles.list}>
          {list.map((item: any, i: number) => {
            return (
              <Flex justify="between" key={i} className={styles['list-item']} onClick={() => pickItem(item)}>
                <div>{item.country}</div>
                <div>+{item.areaCode}</div>
              </Flex>
            )
          })}
          {list.length === 0 && (
            <div className={styles['view-empty']}>{`“${country}”搜索不到`}</div>
          )}
        </div>
      )}
    </div>
  )
}