import React, { Fragment } from 'react';
import styles from './MyInviteCenter.less';
import { Button, Flex, Toast, Icon, Drawer, Modal } from 'antd-mobile'
import { getCountryPhoneCode, sendSmsCode, bySmsCode, getInviteQrCode, getInviteStat } from '@/services/api'
import { getQueryString } from '@/utils/Url'
import { history } from 'umi';
import AreaSelect from '@/components/AreaSelect'
import Cookie from '@/utils/Cookie'

interface IProps {

}

interface IState {
  [propsName: string]: any,
  name: string,
  loginSuccess: boolean
}


class MyInviteCenter extends React.Component<IProps, IState> {
  timer: any
  timer2: any

  constructor(props: any) {
    super(props)
    this.state = {
      name: '',
      userId: getQueryString('u'),
      loginSuccess: false,
      inviteCode: getQueryString('i'),
      agentId: getQueryString('a'),
      countryId: '1',
      areaCode: '86',
      userInfo: {},
      inviteCount: 0,
      rewardStar: 0
    }
  }

  componentDidMount() {
    //window.document.title = '邀好友 赚收益'
    let userInfo: any = window.sessionStorage.getItem('userInfo')
    userInfo = JSON.parse(userInfo) || {}
    const success = userInfo.userId ? true : false
    this.setState({ userInfo, success }, () => {
      if (success) {
        this.getInviteQrCode(userInfo.userId)
        this.getInviteStat()    //获取统计
      }
    })
  }

  componentWillUnmount() {
    clearTimeout(this.timer)
    clearTimeout(this.timer2)
  }

  handleInput(name: string, e: any) {
    const state: any = this.state
    state[name] = e.target.value
    this.setState(state)
  }

  handleBlur() {
    this.timer = setTimeout(() => {
      // 软键盘收起的事件处理
      let ua = navigator.userAgent.toLowerCase();
      if (ua.indexOf('iphone') > 0 || ua.indexOf('ipad') > 0) {
        // 键盘收齐页面空白问题
        window.scroll(0, 0)
      }
    }, 200)
  }

  handleFocus() {
    if (this.timer) {
      clearTimeout(this.timer)
    }
  }

  //发送验证码
  async sendSmsCode() {
    const { phone } = this.state
    if (!phone) {
      Toast.fail('请输入手机号码', 1)
      return
    }
    const params = {
      phone,
      codeType: 101,
      countryId: 1
    }
    Toast.loading('发送验证码中', 0)
    const res = await sendSmsCode(params)
    console.log('验证码: ', res)
    if (res.success) {
      Toast.success('验证码发送成功', 1)
      //测试环境直接填入验证码
      if (res.data.code) {
        this.setState({ code: res.data.code })
      } else {
        this.setState({ seconds: 60 }, () => { this.countDown() })
      }
    } else {
      Toast.fail(res.msg, 1)
    }
  }

  //倒计时
  countDown() {
    const { seconds } = this.state
    if (seconds > 0) {
      this.timer2 = setTimeout(() => {
        this.setState({ seconds: seconds - 1 }, () => {
          this.countDown()
        })
      }, 1000);
    }
  }

  onSubmit = async () => {
    const { inviteCode, phone, code } = this.state
    if (!phone) {
      Toast.info('请输入手机号码')
      return
    }
    if (!code) {
      Toast.info('请输入验证码')
      return
    }
    Toast.loading('注册/登录', 0)

    const params = {
      phone,
      code,
      inviteCode,
      countryId: 1
    }
    const res = await bySmsCode(params)
    Toast.hide()
    if (res.success) {
      const userInfo = res.data
      Cookie.set('_xy_invite_h5', res.data.token)
      window.sessionStorage.setItem('userInfo', JSON.stringify(userInfo))
      this.setState({ success: true, userInfo }, () => {
        this.getInviteQrCode(userInfo.userId)
        this.getInviteStat()
      })
    } else {
      Toast.info(res.msg, 2)
    }
  }

  //获取邀请码
  getInviteQrCode = async (userId: string) => {
    const res = await getInviteQrCode({ userId })
    if (res.success) {
      this.setState({ inviteCode: res.data.inviteCode })
    }
  }

  //获取统计
  getInviteStat = async () => {
    const { agentId } = this.state
    if (!agentId) return
    const res = await getInviteStat({ agentId })
    if (res.success) {
      const { inviteCount, rewardStar } = res.data
      this.setState({ inviteCount, rewardStar })
    }
  }

  pickCountry = (info: any) => {
    console.log(info)
    const areaCode = info.areaCode
    const countryId = info.countryId
    this.setState({ areaModal: false, areaCode, countryId })
  }

  openRule = () => {

    this.setState({ ruleModal: true })
  }

  goBanner = () => {
    const { userInfo, inviteCode } = this.state
    history.push(`/channel/banner?u=${userInfo.userId}&i=${inviteCode}`)
  }

  render() {
    const { phone, code, seconds, inviteCode, inviteCount, success, rewardStar, agentId } = this.state
    return (
      <Drawer
        className="my-drawer"
        sidebarStyle={{ border: '1px solid #ddd', width: '90%' }}
        sidebar={<AreaSelect pickItem={this.pickCountry} />}
        open={this.state.areaModal}
        onOpenChange={areaModal => this.setState({ areaModal })}
      >
        <div className={styles.home}>
          <img className={styles.banner} src="http://sp.qn.paqukeji.com/images/20200528_img_01.png" />
          <div className={styles['view-rule']} onClick={this.openRule}>说明</div>
          {success ? (
            <Success
              goBanner={this.goBanner}
              inviteCode={inviteCode}
              inviteCount={inviteCount}
              rewardStar={rewardStar}
              agentId={agentId}
            />
          ) : (
              <Fragment>
                <div className={styles.container}>
                  <img className={styles['login-title']} src={require('@/assets/login_title.png')} />
                  <div style={{ position: 'relative' }}>
                    <input
                      className={styles['input-phone']}
                      placeholder="请输入您的手机号码"
                      value={phone}
                      onChange={this.handleInput.bind(this, 'phone')}
                      onBlur={this.handleBlur.bind(this)}
                      onFocus={this.handleFocus.bind(this)}
                      type="number"
                    />
                    <div className={styles['phone-area']} onClick={() => { this.setState({ areaModal: true }) }}>
                      <span>+{this.state.areaCode || 86}</span>
                      <Icon type="down" size="xxs" style={{ verticalAlign: 'middle' }} />
                    </div>
                  </div>
                  <div className={styles['code-bar']}>
                    <input
                      className={styles.input}
                      placeholder="请输入短信验证码"
                      value={code}
                      onChange={this.handleInput.bind(this, 'code')}
                      onBlur={this.handleBlur.bind(this)}
                      onFocus={this.handleFocus.bind(this)}
                    />
                    <Button
                      className={styles['button-code']}
                      type="ghost"
                      size="small"
                      disabled={!phone || seconds > 0}
                      onClick={this.sendSmsCode.bind(this)}
                    >{seconds > 0 ? seconds + 's' : '获取验证码'}</Button>
                  </div>
                  <div className={styles['button-submit']} onClick={this.onSubmit.bind(this)}>立即登录</div>
                </div>
              </Fragment>
            )}
        </div>
        <Modal
          className={styles['rule-modal']}
          popup
          visible={this.state.ruleModal}
          onClose={() => this.setState({ ruleModal: false })}
          animationType="slide-up"
        >
          <div className={styles.content}>
            <ul className={styles.title}>已成功邀请的人数：</ul>
            <ul> 是通过您的邀请海报，成功注册的人数；</ul>
            <ul className={styles.title}> 公会主播被打赏收益：</ul>
            <ul>是您邀请的好友，对您公会主播的打赏。</ul>
            <ul><span style={{ fontWeight: 'bold' }}>注：</span>您邀请好友所获得收益，请依照您所在公会的制度计算；在这里不做显示。</ul>
          </div>
        </Modal>
      </Drawer>
    )
  }
}

export default MyInviteCenter

//登录成功
function Success(props: any) {

  return (
    <Fragment>
      <div className={`${styles.container} ${styles.success}`}>
        <img className={styles['login-title']} src={require('@/assets/success_title.png')} />
        <Flex align="center">
          <div style={{ width: '2rem' }}>已成功邀请:</div>
          <div><span className="font-60 color-red">{props.inviteCount}</span> 人</div>
        </Flex>
        <Flex align="center">
          <div style={{ minWidth: '2rem' }}>
            <div>公会主播</div>
            <div>被打赏收益:</div>
          </div>
          <div><span className="font-60 color-red">{props.rewardStar}</span> 星钻</div>
        </Flex>
        <div className={styles['button-submit']} onClick={props.goBanner}>{props.inviteCode ? '邀请好友' : <Icon type="loading" />}</div>
        <div className={styles['text-check']} onClick={() => history.push('/channel/record?a=' + props.agentId)}>查看详情 ></div>
      </div>
    </Fragment>
  )
}
